@@ -11,7 +11,7 @@
         x <- as.declared (x)
     }
 
-    if (!(is.atomic (x) && is.numeric (x))) {
+    if (is.null(x) || !is.atomic (x) || !is.numeric (x)) {
         stopError_ ("'x' should be an atomic numerical vector.")
     }
 
@@ -30,7 +30,11 @@
         return (qs)
     }
 
-    if (!(is.atomic (wt) && all (is.finite (na.omit (wt))))) {
+    if (
+        !is.null(wt) && !(
+            is.atomic (wt) && all (is.finite (na.omit (wt)))
+        )
+    ) {
         stopError_ ("'wt' should be an atomic vector with finite values.")
     }
 
